Crate libdd_telemetry

Crate libdd_telemetry 

Modules

config
data
info
metrics
worker

Structs

Endpoint
Tag

Functions

build_host
parse_tags
Parse a string of tags typically provided by environment variables The tags are expected to be either space or comma separated: “key1:value1,key2:value2” “key1:value1 key2:value2” Tag names and values are required and may not be empty.
parse_uri
Converts a human-facing URL string into the internal http::Uri representation.