Module config

Module config 

Structs

Config
Settings
Settings gathers configuration options we receive from the environment (either through env variable, or that could be set from the )

Constants

DEFAULT_DD_SITE
PROD_INTAKE_SUBDOMAIN