pub struct Settings {
pub agent_host: Option<String>,
pub trace_agent_port: Option<u16>,
pub trace_agent_url: Option<String>,
pub trace_pipe_name: Option<String>,
pub direct_submission_enabled: bool,
pub api_key: Option<String>,
pub site: Option<String>,
pub telemetry_dd_url: Option<String>,
pub telemetry_heartbeat_interval: Duration,
pub telemetry_extended_heartbeat_interval: Duration,
pub shared_lib_debug: bool,
pub agent_uds_socket_found: bool,
}Expand description
Settings gathers configuration options we receive from the environment (either through env variable, or that could be set from the )
Fields
agent_host: Option<String>trace_agent_port: Option<u16>trace_agent_url: Option<String>trace_pipe_name: Option<String>direct_submission_enabled: boolapi_key: Option<String>site: Option<String>telemetry_dd_url: Option<String>telemetry_heartbeat_interval: Durationtelemetry_extended_heartbeat_interval: Durationagent_uds_socket_found: boolImplementations