Module data

Module data 

Re-exports

pub use payload::*;

Modules

metrics
payload

Structs

AppClientConfigurationChange
AppDependenciesLoaded
AppEndpoints
AppIntegrationsChange
AppProductChange
AppStarted
Application
Configuration
ConfigurationOriginIter
An iterator over the variants of ConfigurationOrigin
Dependency
DependencyKey
SCA metadata may be attached to a dependency after it was first reported; keying the store by this instead of the full struct means that update refreshes the existing entry instead of being stored (and re-sent) as a second entry for the same package/version.
DependencyMetadata
Distributions
Endpoint
Error
GenerateMetrics
Host
InstallSignature
Integration
Log
LogLevelIter
An iterator over the variants of LogLevel
Logs
ProductState
Telemetry

Enums

ApiVersion
ConfigurationOrigin
LogLevel
Method