pub struct DependencyKey { /* private fields */ }Expand description
SCA metadata may be attached to a dependency after it was first reported; keying the store by this instead of the full struct means that update refreshes the existing entry instead of being stored (and re-sent) as a second entry for the same package/version.