pub fn parse_tags(str: &str) -> (Vec<Tag>, Option<String>)Expand description
Parse a string of tags typically provided by environment variables The tags are expected to be either space or comma separated: “key1:value1,key2:value2” “key1:value1 key2:value2” Tag names and values are required and may not be empty.
Returns a tuple of the correctly parsed tags and an optional error message describing issues encountered during parsing.