Module worker

Module worker 

Modules

http_client
metric_ring
A bounded multi-producer / single-consumer ring buffer for metric points.
store

Structs

LogIdentifier
Identifies a logging location uniquely
TelemetryWorker
C is the capability bundle. Leaf crates pin it to a concrete type (NativeCapabilities on native, WasmCapabilities on wasm).
TelemetryWorkerBuilder
TelemetryWorkerHandle
TelemetryWorkerHandle is a handle which allows interactions with the telemetry worker. The handle is safe to use across threads.
TelemetryWorkerStats

Enums

LifecycleAction
TelemetryActions
TelemetryWorkerFlavor

Constants

MAX_ITEMS
How many dependencies/integrations/configs we keep in memory at most