pub enum TelemetryWorkerFlavor {
Full,
MetricsLogs,
}Variants
Full
Send all telemetry messages including lifecycle events like app-started, heartbeats, dependencies and configurations
MetricsLogs
Only send telemetry data not tied to the lifecycle of the app like logs and metrics