pub struct Store<T> { /* private fields */ }Expand description
Stores telemetry data item, like dependencies and integrations
- Bounds the length of the collection it uses to prevent memory leaks
- Tries to keep a list of items that it has seen (within max number of items)
- Tries to keep a list of items that haven’t been sent to datadog yet
- Deduplicates items, to make sure we don’t send the item twice
Implementations
Sourceimpl<T> Store<T>
impl<T> Store<T>
pub fn new(max_items: usize) -> Self
pub fn insert(&mut self, item: T)
pub fn unflush_stored(&mut self)
pub fn removed_flushed(&mut self, count: usize)
pub fn flush_not_empty(&self) -> bool
pub fn unflushed(&self) -> impl Iterator<Item = &T>
pub fn len_unflushed(&self) -> usize
pub fn len_stored(&self) -> usize