pub struct LogIdentifier {
pub identifier: u64,
}Expand description
Identifies a logging location uniquely
The identifier is a single 64 bit integer to save space an memory and to be able to generic on the way different languages handle
Fields
identifier: u64Trait Implementations
Sourceimpl Debug for LogIdentifier
impl Debug for LogIdentifier
Sourceimpl<'de> Deserialize<'de> for LogIdentifier
impl<'de> Deserialize<'de> for LogIdentifier
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for LogIdentifier
impl Hash for LogIdentifier
Sourceimpl PartialEq for LogIdentifier
impl PartialEq for LogIdentifier
Sourceimpl Serialize for LogIdentifier
impl Serialize for LogIdentifier
impl Eq for LogIdentifier
impl StructuralPartialEq for LogIdentifier