TelemetryWorkerBuilder

Struct TelemetryWorkerBuilder 

pub struct TelemetryWorkerBuilder {
    pub host: Host,
    pub application: Application,
    pub runtime_id: Option<String>,
    pub dependencies: Store<Dependency, DependencyKey>,
    pub integrations: Store<Integration>,
    pub configurations: Store<Configuration>,
    pub endpoints: Store<Endpoint>,
    pub native_deps: bool,
    pub rust_shared_lib_deps: bool,
    pub config: Config,
    pub flavor: TelemetryWorkerFlavor,
    pub install_signature: Option<InstallSignature>,
}

Fields

host: Hostapplication: Applicationruntime_id: Option<String>dependencies: Store<Dependency, DependencyKey>integrations: Store<Integration>configurations: Store<Configuration>endpoints: Store<Endpoint>native_deps: boolrust_shared_lib_deps: boolconfig: Configflavor: TelemetryWorkerFlavorinstall_signature: Option<InstallSignature>

Implementations

Source

impl TelemetryWorkerBuilder

pub fn new_fetch_host( service_name: String, language_name: String, language_version: String, tracer_version: String, ) -> Self

Creates a new telemetry worker builder and infer host information automatically

pub fn new( hostname: String, service_name: String, language_name: String, language_version: String, tracer_version: String, ) -> Self

Creates a new telemetry worker builder with the given hostname

pub fn build_worker<C: HttpClientCapability + SleepCapability + MaybeSend + Sync + 'static>( self, tokio_runtime: Option<Handle>, ) -> (TelemetryWorkerHandle<C>, TelemetryWorker<C>)

Build the corresponding worker and its handle.

pub fn spawn<C: HttpClientCapability + SleepCapability + MaybeSend + Sync + 'static>( self, ) -> (TelemetryWorkerHandle<C>, JoinHandle<()>)

Spawns a telemetry worker task in the current tokio runtime.

pub fn run<C: HttpClientCapability + SleepCapability + MaybeSend + Sync + 'static>( self, ) -> Result<TelemetryWorkerHandle<C>>

Spawns a telemetry worker in a new thread and returns a handle to interact with it.