Module config

Module config 

Structs

Config
Settings
Settings gathers configuration options we receive from the environment (either through env variable, or that could be set from the )
TelemetryEndpoint
Partial endpoint configuration applied through Config::set_endpoint.

Constants

DEFAULT_DD_SITE
PROD_INTAKE_SUBDOMAIN