Structs
- Config
- Settings
- Settings gathers configuration options we receive from the environment (either through env variable, or that could be set from the )
- Telemetry
Endpoint - Partial endpoint configuration applied through
Config::set_endpoint.
Config::set_endpoint.