Module config
libdd_
telemetry
2.0.0
Module config
Module Items
Structs
Constants
In crate libdd_
telemetry
libdd_telemetry
Module
config
Structs

Config
Settings
Settings gathers configuration options we receive from the environment (either through env variable, or that could be set from the )
Constants

DEFAULT_
DD_
SITE
PROD_
INTAKE_
SUBDOMAIN