Re-exports
pub use payload::*;
Modules
Structs
- AppClient
Configuration Change - AppDependencies
Loaded - AppEndpoints
- AppIntegrations
Change - AppProduct
Change - AppStarted
- Application
- Configuration
- Configuration
Origin Iter - An iterator over the variants of ConfigurationOrigin
- Dependency
- Dependency
Key - SCA metadata may be attached to a dependency after it was first reported; keying the store by this instead of the full struct means that update refreshes the existing entry instead of being stored (and re-sent) as a second entry for the same package/version.
- Dependency
Metadata - Distributions
- Endpoint
- Error
- Generate
Metrics - Host
- Install
Signature - Integration
- Log
- LogLevel
Iter - An iterator over the variants of LogLevel
- Logs
- Product
State - Telemetry