Modules
- http_
client - metric_
ring - A bounded multi-producer / single-consumer ring buffer for metric points.
- store
Structs
- LogIdentifier
- Identifies a logging location uniquely
- Telemetry
Worker Cis the capability bundle. Leaf crates pin it to a concrete type (NativeCapabilitieson native,WasmCapabilitieson wasm).- Telemetry
Worker Builder - Telemetry
Worker Handle - TelemetryWorkerHandle is a handle which allows interactions with the telemetry worker. The handle is safe to use across threads.
- Telemetry
Worker Stats
Enums
Constants
- MAX_
ITEMS - How many dependencies/integrations/configs we keep in memory at most