TelemetryWorkerBuilder

Struct TelemetryWorkerBuilder 

pub struct TelemetryWorkerBuilder {
    pub host: Host,
    pub application: Application,
    pub runtime_id: Option<String>,
    pub dependencies: Store<Dependency>,
    pub integrations: Store<Integration>,
    pub configurations: Store<Configuration>,
    pub native_deps: bool,
    pub rust_shared_lib_deps: bool,
    pub config: Config,
    pub flavor: TelemetryWorkerFlavor,
}

Fields

host: Hostapplication: Applicationruntime_id: Option<String>dependencies: Store<Dependency>integrations: Store<Integration>configurations: Store<Configuration>native_deps: boolrust_shared_lib_deps: boolconfig: Configflavor: TelemetryWorkerFlavor

Implementations

Source

impl TelemetryWorkerBuilder

pub fn new_fetch_host( service_name: String, language_name: String, language_version: String, tracer_version: String, ) -> Self

Creates a new telemetry worker builder and infer host information automatically

pub fn new( hostname: String, service_name: String, language_name: String, language_version: String, tracer_version: String, ) -> Self

Creates a new telemetry worker builder with the given hostname

pub fn build_worker( self, tokio_runtime: Handle, ) -> (TelemetryWorkerHandle, TelemetryWorker)

Build the corresponding worker and it’s handle. The runtime handle is wrapped in the worker handle and should be the one used to run the worker task.

pub fn spawn(self) -> (TelemetryWorkerHandle, JoinHandle<()>)

Spawns a telemetry worker task in the current tokio runtime The worker will capture a reference to the runtime and use it to run its tasks

pub fn run(self) -> Result<TelemetryWorkerHandle>

Spawns a telemetry worker in a new thread and returns a handle to interact with it